using System.Reflection;
using System.Runtime.CompilerServices;
using System.Runtime.InteropServices;
using MySQL.GUI.Workbench;

// General Information about an assembly is controlled through the following 
// set of attributes. Change these attribute values to modify the information
// associated with an assembly.
[assembly: AssemblyTitle("MySQL Workbench")]
[assembly: AssemblyDescription("MySQL Database Design + SQL Work Tool")]
[assembly: AssemblyConfiguration("development")]
[assembly: AssemblyCompany("Oracle Corporation")]
[assembly: AssemblyProduct("MySQL Workbench")]
[assembly: AssemblyCopyright("Copyright © 2006, 2017, Oracle and/or its affiliates")]
[assembly: AssemblyTrademark("")]
[assembly: AssemblyCulture("")]

// Setting ComVisible to false makes the types in this assembly not visible 
// to COM components.  If you need to access a type in this assembly from 
// COM, set the ComVisible attribute to true on that type.
[assembly: ComVisible(false)]

// The following GUID is for the ID of the typelib if this project is exposed to COM
[assembly: Guid("ff29df99-51b2-4792-8bdf-69e5ee8df428")]

// Version information for an assembly consists of the following four values:
//
//      Major Version
//      Minor Version 
//      Release Number
//
[assembly: AssemblyVersion("6.3.10")]
[assembly: AssemblyFileVersion("6.3.10")]
